@@ -11,9 +11,6 @@ class RelatedContentField(GenericRelation):
         }
         defaults.update(kwargs)
         super(RelatedContentField, self).__init__(RelatedContent, **defaults)
-
-try:
-    from south.modelsinspector import add_ignored_fields
-    add_ignored_fields(["^armstrong\.apps\.related_content\.fields\.RelatedContentField"])
-except ImportError:
-    pass
+        
+from south.modelsinspector import add_ignored_fields
+add_ignored_fields(["^armstrong\.apps\.related_content\.fields\.RelatedContentField"])
\ No newline at end of file
